## 股本情况（盘前）

接口：stk_premarket

描述：每日开盘前获取当日股票的股本情况，包括总股本和流通股本，涨跌停价格等。

限量：单次最大8000条数据，可循环提取

权限：与积分无关，需单独开权限

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 股票代码 |
| trade_date | str | N | 交易日期(YYYYMMDD格式，下同) |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| trade_date | str | Y | 交易日期 |
| ts_code | str | Y | TS股票代码 |
| total_share | float | Y | 总股本（万股） |
| float_share | float | Y | 流通股本（万股） |
| pre_close | float | Y | 昨日收盘价 |
| up_limit | float | Y | 今日涨停价 |
| down_limit | float | Y | 今日跌停价 |

接口示例

```python
pro = ts.pro_api()

#获取某一日盘前所有股票当日的最新股本
df = pro.stk_premarket(trade_date='20240603')
```

数据示例

```python
trade_date    ts_code  total_share  float_share pre_close up_limit down_limit
0      20240603  001387.SZ   17778.8000    4355.7297    17.000   18.700     15.300
```